@@ -1,8 +1,11 @@
+import { BehaviorSubject } from "rxjs";
+import { takeUntil } from "rxjs/operators";
 import { ChangeDetectionStrategy, Component } from "@angular/core";
 import { HeaderService } from "@synerty/peek-plugin-base-js";
 import { NgLifeCycleEvents, VortexStatusService } from "@synerty/vortexjs";
-import { BehaviorSubject } from "rxjs";
-import { Network } from "@capacitor/network";
+import { Plugins } from "@capacitor/core";
+
+const { Network } = Plugins;
 
 @Component({
     selector: "status-component",
@@ -21,7 +24,6 @@ export class StatusComponent extends NgLifeCycleEvents {
         public headerService: HeaderService
     ) {
         super();
-        this.isVortexOnline = vortexStatusService.snapshot.isOnline;
     }
 
     get isOnline() {
@@ -45,7 +47,7 @@ export class StatusComponent extends NgLifeCycleEvents {
             this.isOnline = status.connected;
         });
         this.vortexStatusService.isOnline
-            .takeUntil(this.onDestroyEvent)
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe((value) => (this.isVortexOnline = value));
     }
 }
